CipherSuite

Trait CipherSuite 

pub trait CipherSuite{
    type OprfCs: CipherSuite;
    type KeyExchange: KeyExchange;
    type Ksf: Ksf;
}
Configures the underlying primitives used in OPAQUE

  • OprfCs: A VOPRF ciphersuite, see voprf::CipherSuite.
  • KeGroup: A Group used for the KeyExchange.
  • KeyExchange: The key exchange protocol to use in the login step
  • Hash: The main hashing function to use
  • Ksf: A key stretching function, typically used for password hashing

Required Associated Types

type OprfCs: CipherSuite

A VOPRF ciphersuite, see voprf::CipherSuite.

type KeyExchange: KeyExchange

A key exchange protocol

type Ksf: Ksf

A key stretching function, typically used for password hashing

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors