Module hash

Module hash 

A convenience trait for digest bounds used throughout the library

Traits

Hash
Trait inheriting the requirements from Digest for compatibility with HKDF and HMAC Associated types could be simplified when they are made as defaults: https://github.com/rust-lang/rust/issues/29661
ProxyHash
Trait to simplify requirements for Hash.