Hash

Trait Hash 

pub trait Hash:
    Default
    + HashMarker
    + Digest
    + OutputSizeUser<OutputSize = <<Self as CoreProxy>::Core as OutputSizeUser>::OutputSize>
    + BlockSizeUser
    + FixedOutputReset
    + CoreProxy
    + Clone
    + ZeroizeOnDrop{ }
Trait inheriting the requirements from Digest for compatibility with HKDF and HMAC Associated types could be simplified when they are made as defaults: https://github.com/rust-lang/rust/issues/29661

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors