pub struct ClientLoginStartResult<CS: CipherSuite> {
pub message: CredentialRequest<CS>,
pub state: ClientLogin<CS>,
}Expand description
Contains the fields that are returned by a client login start
Fields
message: CredentialRequest<CS>The message to send to the server to begin the login protocol
state: ClientLogin<CS>The state that the client must keep in order to complete the protocol