KeyMaterialInfo

Struct KeyMaterialInfo 

pub struct KeyMaterialInfo<'ci, OS: Clone> {
    pub ikm: OS,
    pub info: [&'ci [u8]; 2],
}
The information required to generate the key material for ServerRegistration::start_with_key_material() and ServerLogin::builder_with_key_material().

Use a HKDF, with the input key material ikm, expand operation with info with an output length of CS::OprfCs::ScalarLen.

Fields

ikm: OS

Input key material for the HKDF.

info: [&'ci [u8]; 2]

Info for the HKDF expand operation.