pub struct ServerLoginParameters<'c, 'i> {
pub context: Option<&'c [u8]>,
pub identifiers: Identifiers<'i>,
}Expand description
Optional parameters for server login start and finish
Fields
context: Option<&'c [u8]>Specifying a context field that the client must agree on
identifiers: Identifiers<'i>Specifying a user identifier and server identifier that will be matched against the client