pub struct ServerRegistrationStartResult<CS: CipherSuite> {
pub message: RegistrationResponse<CS>,
}Expand description
Contains the fields that are returned by a server registration start. Note that there is no state output in this step
Fields
message: RegistrationResponse<CS>The registration resposne message to send to the client