ServerSetup

Struct ServerSetup 

pub struct ServerSetup<CS: CipherSuite, SK: Clone = PrivateKey<<CS::KeyExchange as KeyExchange>::Group>, OS: Clone = OprfSeed<<CS::OprfCs as CipherSuite>::Hash>> { /* private fields */ }
The state elements the server holds upon setup

Implementations

Source

impl<CS: CipherSuite> ServerSetup<CS, PrivateKey<<CS::KeyExchange as KeyExchange>::Group>>

pub fn new<R: CryptoRng + Rng>(rng: &mut R) -> Self

Generate a new instance of server setup

Source

impl<CS: CipherSuite, SK: Clone, OS: Clone> ServerSetup<CS, SK, OS>

pub fn new_with_key_pair_and_seed<R: CryptoRng + Rng>( rng: &mut R, keypair: KeyPair<<CS::KeyExchange as KeyExchange>::Group, SK>, oprf_seed: OS, ) -> Self

Create ServerSetup with the given keypair and OPRF seed.

This function should not be used to restore a previously-existing instance of ServerSetup. Instead, use ServerSetup::serialize and ServerSetup::deserialize for this purpose.

pub fn key_material_info<'ci>( &self, credential_identifier: &'ci [u8], ) -> KeyMaterialInfo<'ci, OS>

The information required to generate the key material for ServerRegistration::start_with_key_material() and ServerLogin::builder_with_key_material().

pub fn serialize( &self, ) -> GenericArray<u8, Sum<Sum<OS::Len, SK::Len>, <<CS::KeyExchange as KeyExchange>::Group as Group>::PkLen>>

Serialization into bytes

pub fn deserialize(input: &[u8]) -> Result<Self, ProtocolError<SK::Error>>

Deserialization from bytes

pub fn keypair(&self) -> &KeyPair<<CS::KeyExchange as KeyExchange>::Group, SK>

Returns the keypair

Source

impl<CS: CipherSuite, SK: Clone> ServerSetup<CS, SK>

pub fn new_with_key_pair<R: CryptoRng + Rng>( rng: &mut R, keypair: KeyPair<<CS::KeyExchange as KeyExchange>::Group, SK>, ) -> Self

Create ServerSetup with the given keypair

This function should not be used to restore a previously-existing instance of ServerSetup. Instead, use ServerSetup::serialize and ServerSetup::deserialize for this purpose.