pub struct ClientLoginFinishResult<CS: CipherSuite> {
pub message: CredentialFinalization<CS>,
pub session_key: Output<<CS::KeyExchange as KeyExchange>::Hash>,
pub export_key: Output<<CS::OprfCs as CipherSuite>::Hash>,
pub server_s_pk: PublicKey<<CS::KeyExchange as KeyExchange>::Group>,
}Expand description
Contains the fields that are returned by a client login finish
Fields
message: CredentialFinalization<CS>The message to send to the server to complete the protocol
session_key: Output<<CS::KeyExchange as KeyExchange>::Hash>The session key
export_key: Output<<CS::OprfCs as CipherSuite>::Hash>The client-side export key
server_s_pk: PublicKey<<CS::KeyExchange as KeyExchange>::Group>The server’s static public key