pub struct ServerLoginBuilder<'a, CS: CipherSuite, SK: Clone> { /* private fields */ }Expand description
Builder for ServerLogin when using remote keys.
Implementations
Sourceimpl<CS: CipherSuite, SK: Clone> ServerLoginBuilder<'_, CS, SK>
impl<CS: CipherSuite, SK: Clone> ServerLoginBuilder<'_, CS, SK>
Sourcepub fn data(&self) -> <CS::KeyExchange as KeyExchange>::KE2BuilderData<'_, CS>
pub fn data(&self) -> <CS::KeyExchange as KeyExchange>::KE2BuilderData<'_, CS>
The returned data here has to be processed and the result given as an
input to ServerLoginBuilder::build(). To understand what kind of
output is expected here and how to process it, refer to the
documentation of your chosen CipherSuite::KeyExchange.
Sourcepub fn private_key(&self) -> &SK
pub fn private_key(&self) -> &SK
The handle to the corresponding ServerSetups private key.
Sourcepub fn build(
self,
input: <CS::KeyExchange as KeyExchange>::KE2BuilderInput<CS>,
) -> Result<ServerLoginStartResult<CS>, ProtocolError>
pub fn build( self, input: <CS::KeyExchange as KeyExchange>::KE2BuilderInput<CS>, ) -> Result<ServerLoginStartResult<CS>, ProtocolError>
Build ServerLogin after attaining the input for the key exchange. To
understand what kind of input is expected here, refer to the
documentation of your chosen CipherSuite::KeyExchange.
See ServerLogin::start() for the regular path.